"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var ora_1 = __importDefault(require("ora"));
var chalk_1 = __importDefault(require("chalk"));
var crypto_1 = __importDefault(require("crypto"));
var types_1 = require("../store/types");
var running = false;
var spin = false;
var spinner = ora_1.default('');
function createColorHash(name, index) {
    if (index === void 0) { index = 0; }
    var hash = name
        ? crypto_1.default
            .createHash('md5')
            .update(name)
            .digest('hex')
            .slice(0, 6)
        : '000000';
    var array = hash.split('');
    array[index + 0] = 'f';
    array[index + 1] = 'f';
    return '#' + array.join('');
}
function Logger(config) {
    if (config === void 0) { config = {}; }
    config = __assign({ characterLimit: 80, collapseErrors: false, spinOnFirstUser: true, filter: ['task'], removeFromStore: true, moreColors: true }, config);
    return function (store) { return function (next) { return function (action) {
        if (action.type === types_1.updateGlobals && action.running !== undefined) {
            running = action.running;
            if (!config.spinOnFirstUser && running)
                spin = true;
        }
        else if (action.type === types_1.log && (!config.filter || !config.filter.includes(action.args.owner))) {
            if (config.spinOnFirstUser && action.args.owner === 'user' && running)
                spin = true;
            var level = action.level, text = action.text;
            var _a = action.args, owner = _a.owner, user = _a.user, worker = _a.worker, task = _a.task, duration = _a.duration;
            var colors = { system: 'bgBlue', user: 'blue', worker: 'white', task: 'cyan' };
            var receiving = text.startsWith('receiv');
            var separating = text.startsWith('-');
            owner = owner.slice(0, 6);
            //$FlowFixMe
            owner = chalk_1.default[(config.moreColors && colors[owner]) || 'white'](new Array(6 - owner.length).fill(' ').join('') + owner.toUpperCase());
            worker = chalk_1.default.hex(createColorHash(worker, 0))(worker ? '◼' : ' ');
            user = chalk_1.default.hex(createColorHash(user, 2))(user ? '◼' : ' ');
            task = chalk_1.default.hex(createColorHash(task, 4))(task ? '◼' : ' ');
            if (action.args.owner === 'system' && separating) {
                worker = chalk_1.default.white('◼ ') + chalk_1.default.blue('◼ ') + chalk_1.default.cyan('◼ ') + chalk_1.default.white('Worker');
                user = chalk_1.default.blue('User');
                task = chalk_1.default.cyan('Task');
                text = '';
            }
            if (level !== 'error' || config.collapseErrors) {
                if (duration)
                    text = duration.toFixed(2) + "ms " + text;
                text = text.slice(0, config.characterLimit);
                if (receiving)
                    text = chalk_1.default.dim(text);
            }
            text = owner + " " + worker + " " + user + " " + task + " " + text;
            if (level === 'info' && text.includes('accept'))
                spinner.succeed(text);
            else if (level === 'info')
                spinner.stopAndPersist({ text: config.moreColors ? chalk_1.default.cyan(text) : text });
            else if (level === 'log')
                spinner.stopAndPersist({ text: text });
            else if (level === 'warn')
                spinner.warn(chalk_1.default.yellow(text));
            else if (level === 'error')
                spinner.fail(chalk_1.default.red(text));
            running && spin && spinner.start();
        }
        if (action.type === types_1.log && action.level !== 'error' && config.removeFromStore)
            return;
        return next(action);
    }; }; };
}
exports.default = Logger;
//# sourceMappingURL=logger.js.map