import { TaskNullableType, StateType, IdType } from '../../types';
/**
 * Creates and pushes a task, this will trigger unoccupied workers to execute it.
 * The result will be a promise that resolves to the finished task
 *
 * @param {any | Array<any>} commands
 * @param {IdType | void} user
 * @param {IdType = guid.raw()} task
 * @param {IdType} worker
 */
export declare function createTask(commands: any | Array<any>, user: IdType | void, task?: IdType, worker?: IdType): (dispatch: any, getState: () => StateType) => Promise<any>;
/**
 * Pushes a global or worker-bound task
 *
 * @param {IdType} task
 * @param {IdType | void} user
 * @param {Array<string>} commands
 * @param {Promise<any>} promise
 * @param {any} resolve
 * @param {any} reject
 * @param {string | void} worker
 * @param {number} timestamp
 */
export declare function pushTask(task: IdType, user: IdType | void, commands: Array<string>, promise: Promise<any>, resolve: any, reject: any, worker: string | void, timestamp?: number): {
    type: string;
    task: string;
    user: string | void;
    commands: string[];
    promise: Promise<any>;
    resolve: any;
    reject: any;
    worker: string | void;
    timestamp: number | undefined;
};
/**
 * Removes a task, this is used by the worker once it has resolved a task
 *
 * @param {IdType} task
 * @param {IdType} worker
 */
export declare function removeTask(task: IdType, worker?: IdType): {
    type: string;
    worker: string | undefined;
    task: string;
};
/**
 * Update task
 *
 * @param {IdType} task
 * @param {IdType | void} worker
 * @param {TaskNullableType} props
 */
export declare function updateTask(task: IdType, worker: IdType | void, props: TaskNullableType): {
    results?: any[] | undefined;
    streamData?: any;
    type: string;
    worker: string | void;
    task: string;
};
/**
 * Observe tasks and workers, every reaction triggers the observer to look for unfulfileld
 * tasks that should then be applied to workers signaling their availability by the occupid flag
 */
export declare function handleTasks(): (dispatch: any, getState: () => StateType) => Promise<any>;
