import { WorkerNullableType, TaskType, StateType, IdType, ServerType } from '../../types';
/**
 * Adds new worker
 *
 * @param {IdType} worker
 * @param {*} socket
 */
export declare function addWorker(worker: IdType, socket: any): (dispatch: any) => void;
/**
 * Updates existig worker
 *
 * @param {IdType} worker
 * @param {WorkerNullableType} updates
 */
export declare function updateWorker(worker: IdType, updates: WorkerNullableType): {
    type: string;
    worker: string;
    updates: WorkerNullableType;
};
/**
 * Removes existing worker. Force==true will kill the worker right away, then collect open tasks in order
 * to push them to the global queue again so another unoccupied worker may pick them up. If force==false
 * then it will wait until the worker has resolved its open tasks first, then kill it.
 *
 * @param {IdType} worker
 * @param {boolean = false} force
 */
export declare function removeWorker(worker: IdType, force?: boolean): (dispatch: any, getState: () => StateType) => Promise<void>;
/**
 * Sends a task or a series of commands to a worker
 *
 * @param {IdType} worker
 * @param {*} payload
 */
export declare function execute(worker: IdType, payload: any): (dispatch: any, getState: () => StateType) => Promise<any>;
/**
 * Clears worker
 *
 * @param {IdType} worker
 */
export declare function clear(worker: IdType): (dispatch: any, getState: () => StateType) => Promise<void>;
/**
 * This marks a workers task as completed and resolves & removes it
 *
 * @param {IdType} worker
 * @param {IdType} taskId
 */
export declare function resolveWorkerTask(worker: IdType, taskId: IdType): (dispatch: any, getState: () => StateType) => void;
/**
 * Marks a worker as occupied, removes a group of tasks and returns a resolver that should be called
 * once all of the tasks have been resolved.
 *
 * @param {IdType} worker
 * @param {IdType} user
 * @param {Array<TaskType>} tasks
 */
export declare function claimWorker(worker: IdType, user: IdType, tasks: Array<TaskType>): (dispatch: any) => void;
/**
 * Resolves worker and signals it free for the taking
 *
 * @param {IdType} worker
 */
export declare function releaseWorker(worker: IdType): (dispatch: any, getState: () => StateType) => void;
/**
 * Forwards results to receiver, may be a users socket or the tasks result collection
 *
 * @param {IdType} worker
 * @param {IdType} task
 * @param {Object} data
 */
export declare function emitWorkerTask(worker: IdType, task: IdType, data: any): (dispatch: any, getState: () => StateType) => void;
/**
 * Deals with a workers socket and dispatches further actions
 *
 * @param {*} socket
 */
export declare function handleWorker(socket: any): (dispatch: any, getState: () => StateType) => void;
/**
 * Spawns a local worker instance and awaits its ready state
 *
 * @param {number = 3} tries
 */
export declare function spawnWorker(tries?: number): (dispatch: any, getState: () => StateType, server: ServerType) => Promise<any>;
