import { Store } from 'redux';
import * as actions from './store/actions';
export declare type IdType = string;
export declare type LogType = {
    type: string;
    args: [];
};
export declare type GlobalsType = {
    running: boolean;
    cpu: number;
    spawned: number;
    log: Array<LogType>;
    tasks: number;
};
export declare type GlobalsNullableType = {
    running?: boolean;
    cpu?: number;
    spawned?: number;
    tasks?: number;
    log?: any[];
};
export declare type ConfigType = {
    executable: string;
    configurationData: string;
    output: string;
    protocol: string;
    serverOptions: any;
    ip: string;
    privatePort: number;
    publicPort: number;
    binary: boolean;
    multipart: boolean;
    compression: boolean;
    sendTreePatches: boolean;
    stdout: boolean;
    secureApi: boolean;
    instances: number;
    debug: boolean;
    showConsole: boolean;
    stateDebounce: number;
    maxStates: number;
    workerTimeout: number;
    restTimeout: number;
    pingTimeout: number;
    pingInterval: number;
    collectResultsOnly: boolean;
    logExpirationDays: number;
    disableGraphics: boolean;
    enableInvisibleGraphics: boolean;
    enableTaskSalvaging: boolean;
    exec: string;
    execArgs: Array<string>;
};
export declare type ConfigNullableType = {
    executable?: string;
    configurationData?: string;
    output?: string;
    protocol?: string;
    serverOptions?: any;
    ip?: string;
    privatePort?: number;
    publicPort?: number;
    binary?: boolean;
    multipart?: boolean;
    compression?: boolean;
    sendTreePatches?: boolean;
    stdout?: boolean;
    secureApi?: boolean;
    instances?: number;
    debug?: boolean;
    showConsole?: boolean;
    stateDebounce?: number;
    maxStates?: number;
    workerTimeout?: number;
    restTimeout?: number;
    pingTimeout?: number;
    pingInterval?: number;
    collectResultsOnly?: boolean;
    enableTaskSalvaging?: boolean;
    logExpirationDays?: number;
    exec?: string;
    execArgs?: Array<string>;
};
export declare type TaskType = {
    id: IdType;
    user: string;
    commands: Array<string>;
    promise: Promise<any>;
    resolve: Function;
    reject: Function;
    results: Array<any>;
    streamData: any | void;
    timestamp: number;
    duration: number;
};
export declare type TaskNullableType = {
    results?: Array<any>;
    streamData?: any | void;
};
export declare type WorkerType = {
    id: IdType;
    alive: boolean;
    lastUser: string;
    occupied: boolean;
    timestamp: number;
    sequence: Promise<any>;
    resolve: Function;
    socket: any;
    process: any;
    tasks: Array<TaskType>;
};
export declare type WorkerNullableType = {
    lastUser?: any;
    process?: any;
    alive?: boolean;
};
export declare type UserType = {
    id: IdType;
    socket: any;
    timestamp: number;
    folder: string;
    systemFile: string;
    stateFiles: Array<string>;
    queue: any;
    actions: number;
};
export declare type UserNullableType = {
    folder?: string;
    systemFile?: string;
    stateFiles?: Array<string>;
    queue?: any;
    actions?: number;
};
export declare type CollectionsType = {
    workers: Array<IdType>;
    users: Array<IdType>;
};
export declare type LogNullableType = {
    owner?: string;
    worker?: IdType | void;
    user?: IdType | void;
    task?: IdType | void;
    duration?: number;
};
export declare type StateType = {
    globals: GlobalsType;
    config: ConfigType;
    tasks: Array<TaskType>;
    workers: Record<IdType, WorkerType>;
    users: Record<IdType, UserType>;
    collections: CollectionsType;
};
export declare type ServerType = {
    store: Store;
    actions: typeof actions;
    express: any;
    socket: any;
    io: any;
    ws: any;
};
